==> otp_verification-8.x-1.0.tar.gz: otp_verification/src/MiniorangeOtpUtilities.php <==
<?php
/**
 * @file
 * This file is part of miniOrange OTP Verification plugin.
 */
namespace Drupal\otp_verification;
use Drupal\Tests\field\Functional\reEnableModuleFieldTest;
use Drupal\otp_verification\MiniorangeOtpVerificationConstants;
use http\Encoding\Stream\Enbrotli;

/**
 * OTP Utilities Class.
 */
class MiniorangeOtpUtilities {
    public static function AddSupportButton(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['miniorange_saml_JS_for_visual_tour_and_support'] = array(
            '#attached' => array(
                'library' =>array('otp_verification/otp_verification.support',
                'otp_verification/otp_verification.phone')
            ),
        );

        $form['miniorange_saml_idp_support_side_button'] = array(
            '#type' => 'button',
            '#value' => t('Support'),
            '#attributes' => array('style' => 'font-size: 15px;cursor: pointer;text-align: center;width: 150px;height: 35px;
                background: rgba(43, 141, 65, 0.93);color: #ffffff;border-radius: 3px;transform: rotate(90deg);text-shadow: none;
                position: relative;margin-left: -92px;top: 94px;'),
            '#prefix' => '<div id="mosaml-feedback-form" class="mo_saml_table_layout_support_btn">',
            '#suffix' => '<div id="Support_Section" class="mo_saml_table_layout_support_1">',
        );

        $form['markup_support_1'] = array(
            '#markup' => '<h3><b>Feature Request/Contact Us:</b></h3><div>Need any help? We can help you with configuring the module. Just send us a query and we will get back to you soon.<br /></div><br>',
        );

        $form['miniorange_otp_verification_email_address_support'] = array(
            '#type' => 'textfield',
            '#attributes' => array('placeholder' => 'Enter your Email'),
            '#default_value' => \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_admin_email'),
        );

        $form['miniorange_otp_verification_phone_number_support'] = array(
            '#type' => 'textfield',
            '#id'=>'query_phone',
            '#attributes'=>array('class'=>array('query_phone'),),
            '#default_value' => \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_admin_phone'),


        );

        $form['miniorange_otp_verification_support_query_support'] = array(
            '#type' => 'textarea',
            '#clos' => '10',
            '#rows' => '5',
            '#attributes' => array('placeholder' => 'Write your query here'),
        );

        $form['miniorange_saml_support_submit_click'] = array(
            '#type' => 'submit',
            '#value' => t('Submit Query'),
            '#submit' => array('\Drupal\otp_verification\MiniorangeOtpUtilities::send_support_query'),
            '#attributes' => array('style' => 'background: #337ab7;color: #ffffff;text-shadow: 0 -1px 1px #337ab7, 1px 0 1px #337ab7, 0 1px 1px #337ab7, -1px 0 1px #337ab7;box-shadow: 0 1px 0 #337ab7;border-color: #337ab7 #337ab7 #337ab7;display:block;margin-left:auto;margin-right:auto;'),
        );

        $form['miniorange_saml_support_note'] = array(
            '#markup' => '<div><br/>If you want custom features in the plugin, just drop an email to <a href="mailto:drupalsupport@xecurify.com">drupalsupport@xecurify.com</a></div>
                          </div></div><div hidden id="mosaml-feedback-overlay"></div>'
        );
    }

    /**
     * Get Support query data from support form
     */
    public static function send_support_query(&$form, $form_state){
        $email = trim($form['miniorange_otp_verification_email_address_support']['#value']);
        $phone = trim($form['miniorange_otp_verification_phone_number_support']['#value']);
        $query = trim($form['miniorange_otp_verification_support_query_support']['#value']);

        self::send_query($email, $phone, $query);
    }


    public static function send_query($email, $phone, $query)
    {
        if(empty($email)||empty($query)){
            \Drupal::messenger()->addMessage(t('The <b><u>Email</u></b> and <b><u>Query</u></b> fields are mandatory.'), 'error');
            return;
        } elseif(!\Drupal::service('email.validator')->isValid($email)) {
            \Drupal::messenger()->addMessage(t('The email address <b><i>' . $email . '</i></b> is not valid.'), 'error');
            return;
        }
        $support = new MiniorangeOTPVerificationSupport($email, $phone, $query);
        $support_response = $support->sendSupportQuery();
        if($support_response) {
            \Drupal::messenger()->addMessage(t('Thanks for getting in touch! We will get back to you soon.'), 'status');
        }
        else {
            \Drupal::messenger()->addMessage(t('Error sending support query'), 'error');
        }
    }

    /**
     * Advertise 2FA
     */

    public static function Two_FA_Advertisement(array &$form, \Drupal\Core\Form\FormStateInterface $form_state){
        global $base_url;
        $form['markup_idp_attr_hea555der_top_support'] = array(
            '#markup' => '<div class="mo_otp_verification_table_layout_support_1 mo_otp_verification_container" style="height:27em;">',
        );

        $form['miniorangerr_otp_email_address'] = array(
            '#markup' => '<div><h3 class="h_3"  >Looking for a Drupal Two-Factor Authentication(2FA)?<br></h3></div>
                        <div class="mo_adv_tfa"><img src="'.$base_url . '/' . drupal_get_path("module", "otp_verification") . '/includes/images/miniorange_i.png" alt="Simply Easy Learning" height="80px" width="80px" class="mo_img_adv"><h3 class="mo_txt_h3">Two-Factor Authentication (2FA)</h3></div>',

        );
        $form['minioranqege_otp_phone_number'] = array(
            '#markup' => '<div class="mo_paragraph"><p>Two Factor Authentication (2FA) module adds a second layer of authentication at the time of login to secure your Drupal accounts. It is a highly secure and easy to setup module which protects your site from hacks and unauthorized login attempts.</p></div>',
        );

        $form['miniorange_otp_2fa_button'] = array(
            '#markup' => '<div style="align:center;"> <a href="https://www.drupal.org/project/miniorange_2fa" class="mo_btn1 mbtn mo_otp-mbtn-success" target="_blank" id="tfa_btn_download">Download Module</a>
      <a href="https://plugins.miniorange.com/drupal-two-factor-authentication-2fa" class="mo_btn2 mbtn mo_otp-mbtn-primary" target="_blank" id="mo_tfa_btn_know">Know More</a>'

        );
    }

    /**
    * Check if curl is installed.
    */
    public static function isCurlInstalled() {
        if (in_array('curl', get_loaded_extensions())) {
            return 1;
        } else {
            return 0;
        }
    }
    /**
    * Check if customer is registered.
    */
    public static function isCustomerRegistered() {
        if (\Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_admin_email') == NULL ||
            \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_id') == NULL ||
            \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_admin_token') == NULL ||
            \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_api_key') == NULL) {
                return FALSE;
        }
        return TRUE;
    }

    /**
    * Call Service function for customer check.
    */
    public static function callService($customer_id, $api_key, $url, $field_string) {
        if (!self::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "message" => 'PHP cURL extension is not installed or disabled.',
            ));
        }

        $ch = curl_init($url);
        $current_time_in_millis = round(microtime(TRUE) * 1000);
        $string_to_hash = $customer_id . number_format($current_time_in_millis, 0, '', '') . $api_key;
        $hash_value = hash("sha512", $string_to_hash);
        $customer_key_header = "Customer-Key: " . $customer_id;
        $timestamp_header = "Timestamp: " . number_format($current_time_in_millis, 0, '', '');
        $authorization_header = "Authorization: " . $hash_value;
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        // Required for https urls.
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            "Content-Type: application/json",
            $customer_key_header,
            $timestamp_header,
            $authorization_header,
        ));
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
        curl_setopt($ch, CURLOPT_TIMEOUT, 20);
        $content = curl_exec($ch);
        if (curl_errno($ch)) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "message" => curl_errno($ch),
            ));
        }
        curl_close($ch);
        return json_decode($content);
    }

    public static function sendToken($otp_options, $email, $phone){
        $url = 'https://login.xecurify.com/moas/api/auth/challenge';
        $ch = curl_init($url);
        $api_key = \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_api_key');
        $customer_key = \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_id');

        // Current time in milliseconds since midnight, January 1, 1970 UTC.
        $current_time_in_millis = round(microtime(TRUE) * 1000);

        // Creating the Hash using SHA-512 algorithm.
        $string_to_hash = $customer_key . $current_time_in_millis . $api_key;
        $hash_value = hash("sha512", $string_to_hash);

        $customer_key_header = "Customer-Key: " . $customer_key;
        $timestamp_header = "Timestamp: " . $current_time_in_millis;
        $authorization_header = "Authorization: " . $hash_value;

        if($otp_options == 0){
            $fields = array(
                'customerKey' => $customer_key,
                'email' => $email,
                'authType' => 'EMAIL',
                'transactionName' => 'Drupal OTP Verification',
            );
        }
        if($otp_options == 1){
            $fields = array(
                'customerKey' => $customer_key,
                'phone' => $phone,
                'authType' => 'SMS',
                'transactionName' => 'Drupal OTP Verification',
            );
        }
        //echo "<pre>";print_r($fields);exit;
        $field_string = json_encode($fields);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_TIMEOUT, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        //curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
          "Content-Type: application/json",
          $customer_key_header,
          $timestamp_header,
          $authorization_header,)
        );
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);

        $content = curl_exec($ch);
        $trans_status = json_decode($content)->status;
        $tx_id = json_decode($content)->txId;
        curl_close($ch);
    	return array($trans_status, $tx_id);
    }

    public static function Is_Restricted_Domain($email_domain){
      $enable_domain_restriction=\Drupal::config('otp_verification.settings')->get('miniorange_block_domain_value');
      if($enable_domain_restriction===FALSE){
        return FALSE;
      }

      $domain=isset(explode('@', $email_domain)[1]) ? explode('@', $email_domain)[1] : '';
      if(is_null($domain) || empty($domain)){
        return FALSE;
      }

      $blockdomains=\Drupal::config('otp_verification.settings')->get('miniorange_block_domains');
      $blockdomains=explode(';',$blockdomains);
      $white_or_black=\Drupal::config('otp_verification.settings')->get('miniorange_domains_are_white_or_black');
        if($white_or_black==='white'){
            if(array_search($domain, $blockdomains)===FALSE){
                return TRUE;
            }
            else return FALSE;
        }
        elseif ($white_or_black=='black') {
            if(array_search($domain, $blockdomains)===FALSE){
                return FALSE;
            }
            else return TRUE;
        }
    }
    public static function load_user_by_name($name) {
        $users = \Drupal::entityTypeManager()
            ->getStorage('user')
            ->loadByProperties([
                'name' => $name,
            ]);

        return $users ? reset($users) : FALSE;
    }
}

==> otp_verification-8.x-1.1.tar.gz: otp_verification/src/MiniorangeOtpUtilities.php <==
<?php
/**
 * @file
 * This file is part of miniOrange OTP Verification plugin.
 */
namespace Drupal\otp_verification;
use Drupal\Tests\field\Functional\reEnableModuleFieldTest;
use Drupal\otp_verification\MiniorangeOtpVerificationConstants;
use http\Encoding\Stream\Enbrotli;

/**
 * OTP Utilities Class.
 */
class MiniorangeOtpUtilities {
    public static function AddSupportButton(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
    {   
        $config = \Drupal::config('otp_verification.settings');

        $form['miniorange_saml_JS_for_visual_tour_and_support'] = array(
            '#attached' => array(
                'library' =>array('otp_verification/otp_verification.support',
                'otp_verification/otp_verification.phone')
            ),
        );

        $form['miniorange_saml_idp_support_side_button'] = array(
            '#type' => 'button',
            '#value' => t('Support'),
            '#attributes' => array('style' => 'font-size: 15px;cursor: pointer;text-align: center;width: 150px;height: 35px;
                background: rgba(43, 141, 65, 0.93);color: #ffffff;border-radius: 3px;transform: rotate(90deg);text-shadow: none;
                position: relative;margin-left: -92px;top: 94px;'),
            '#prefix' => '<div id="mosaml-feedback-form" class="mo_saml_table_layout_support_btn">',
            '#suffix' => '<div id="Support_Section" class="mo_saml_table_layout_support_1">',
        );

        $form['markup_support_1'] = array(
            '#markup' => '<h3><b>Feature Request/Contact Us:</b></h3><div>Need any help? We can help you with configuring the module. Just send us a query and we will get back to you soon.<br /></div><br>',
        );

        $form['miniorange_otp_verification_email_address_support'] = array(
            '#type' => 'textfield',
            '#attributes' => array('placeholder' => 'Enter your Email'),
            '#default_value' => $config->get('miniorange_otp_verification_customer_admin_email'),
        );

        $form['miniorange_otp_verification_phone_number_support'] = array(
            '#type' => 'textfield',
            '#id'=>'query_phone',
            '#attributes'=>array('class'=>array('query_phone'),),
            '#default_value' => $config->get('miniorange_otp_verification_customer_admin_phone'),


        );

        $form['miniorange_otp_verification_support_query_support'] = array(
            '#type' => 'textarea',
            '#clos' => '10',
            '#rows' => '5',
            '#attributes' => array('placeholder' => 'Write your query here'),
        );

        $form['miniorange_saml_support_submit_click'] = array(
            '#type' => 'submit',
            '#value' => t('Submit Query'),
            '#submit' => array('\Drupal\otp_verification\MiniorangeOtpUtilities::send_support_query'),
            '#attributes' => array('style' => 'background: #337ab7;color: #ffffff;text-shadow: 0 -1px 1px #337ab7, 1px 0 1px #337ab7, 0 1px 1px #337ab7, -1px 0 1px #337ab7;box-shadow: 0 1px 0 #337ab7;border-color: #337ab7 #337ab7 #337ab7;display:block;margin-left:auto;margin-right:auto;'),
        );

        $form['miniorange_saml_support_note'] = array(
            '#markup' => '<div><br/>If you want custom features in the plugin, just drop an email to <a href="mailto:drupalsupport@xecurify.com">drupalsupport@xecurify.com</a></div>
                          </div></div><div hidden id="mosaml-feedback-overlay"></div>'
        );
    }

    /**
     * Get Support query data from support form
     */
    public static function send_support_query(&$form, $form_state){
        $email = trim($form['miniorange_otp_verification_email_address_support']['#value']);
        $phone = trim($form['miniorange_otp_verification_phone_number_support']['#value']);
        $query = trim($form['miniorange_otp_verification_support_query_support']['#value']);

        self::send_query($email, $phone, $query);
    }


    public static function send_query($email, $phone, $query)
    {
        if(empty($email)||empty($query)){
            \Drupal::messenger()->addMessage(t('The <b><u>Email</u></b> and <b><u>Query</u></b> fields are mandatory.'), 'error');
            return;
        } elseif(!\Drupal::service('email.validator')->isValid($email)) {
            \Drupal::messenger()->addMessage(t('The email address <b><i>' . $email . '</i></b> is not valid.'), 'error');
            return;
        }
        $support = new MiniorangeOTPVerificationSupport($email, $phone, $query);
        $support_response = $support->sendSupportQuery();
        if($support_response) {
            \Drupal::messenger()->addMessage(t('Thanks for getting in touch! We will get back to you soon.'), 'status');
        }
        else {
            \Drupal::messenger()->addMessage(t('An error occured while sending support query.'), 'error');
        }
    }

    /**
     * Advertise 2FA
     */

    public static function Two_FA_Advertisement(array &$form, \Drupal\Core\Form\FormStateInterface $form_state){
        global $base_url;
        $form['markup_idp_attr_hea555der_top_support'] = array(
            '#markup' => '<div class="mo_otp_verification_table_layout_support_1 mo_otp_verification_container" style="height:27em;">',
        );

        $form['miniorangerr_otp_email_address'] = array(
            '#markup' => '<div><h3 class="h_3"  >Looking for a Drupal Two-Factor Authentication(2FA)?<br></h3></div>
                        <div class="mo_adv_tfa"><img src="'.$base_url . '/' . drupal_get_path("module", "otp_verification") . '/includes/images/miniorange_i.png" alt="Simply Easy Learning" height="80px" width="80px" class="mo_img_adv"><h3 class="mo_txt_h3">Two-Factor Authentication (2FA)</h3></div>',

        );
        $form['minioranqege_otp_phone_number'] = array(
            '#markup' => '<div class="mo_paragraph"><p>Two Factor Authentication (2FA) module adds a second layer of authentication at the time of login to secure your Drupal accounts. It is a highly secure and easy to setup module which protects your site from hacks and unauthorized login attempts.</p></div>',
        );

        $form['miniorange_otp_2fa_button'] = array(
            '#markup' => '<div style="align:center;"> <a href="https://www.drupal.org/project/miniorange_2fa" class="mo_btn1 mbtn mo_otp-mbtn-success" target="_blank" id="tfa_btn_download">Download Module</a>
      <a href="https://plugins.miniorange.com/drupal-two-factor-authentication-2fa" class="mo_btn2 mbtn mo_otp-mbtn-primary" target="_blank" id="mo_tfa_btn_know">Know More</a>'

        );
    }

    /**
    * Check if curl is installed.
    */
    public static function isCurlInstalled() {
        if (in_array('curl', get_loaded_extensions())) {
            return 1;
        } else {
            return 0;
        }
    }
    /**
    * Check if customer is registered.
    */
    public static function isCustomerRegistered() {

        $config = \Drupal::config('otp_verification.settings');

        if ($config->get('miniorange_otp_verification_customer_admin_email') == NULL ||
            $config->get('miniorange_otp_verification_customer_id') == NULL ||
            $config->get('miniorange_otp_verification_customer_admin_token') == NULL ||
            $config->get('miniorange_otp_verification_customer_api_key') == NULL) {
                return FALSE;
        }
        return TRUE;
    }

    /**
    * Call Service function for customer check.
    */
    public static function callService($customer_id, $api_key, $url, $field_string) {
        if (!self::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "message" => 'PHP cURL extension is not installed or disabled.',
            ));
        }

        $ch = curl_init($url);
        $current_time_in_millis = round(microtime(TRUE) * 1000);
        $string_to_hash = $customer_id . number_format($current_time_in_millis, 0, '', '') . $api_key;
        $hash_value = hash("sha512", $string_to_hash);
        $customer_key_header = "Customer-Key: " . $customer_id;
        $timestamp_header = "Timestamp: " . number_format($current_time_in_millis, 0, '', '');
        $authorization_header = "Authorization: " . $hash_value;
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        // Required for https urls.
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            "Content-Type: application/json",
            $customer_key_header,
            $timestamp_header,
            $authorization_header,
        ));
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
        curl_setopt($ch, CURLOPT_TIMEOUT, 20);
        $content = curl_exec($ch);
        if (curl_errno($ch)) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "message" => curl_errno($ch),
            ));
        }
        curl_close($ch);
        return json_decode($content);
    }

    public static function sendToken($otp_options, $email, $phone){

        $config = \Drupal::config('otp_verification.settings');

        $url = 'https://login.xecurify.com/moas/api/auth/challenge';
        $ch = curl_init($url);
        $api_key = $config->get('miniorange_otp_verification_customer_api_key');
        $customer_key = $config->get('miniorange_otp_verification_customer_id');

        // Current time in milliseconds since midnight, January 1, 1970 UTC.
        $current_time_in_millis = round(microtime(TRUE) * 1000);

        // Creating the Hash using SHA-512 algorithm.
        $string_to_hash = $customer_key . $current_time_in_millis . $api_key;
        $hash_value = hash("sha512", $string_to_hash);

        $customer_key_header = "Customer-Key: " . $customer_key;
        $timestamp_header = "Timestamp: " . $current_time_in_millis;
        $authorization_header = "Authorization: " . $hash_value;

        if($otp_options == 0){
            $fields = array(
                'customerKey' => $customer_key,
                'email' => $email,
                'authType' => 'EMAIL',
                'transactionName' => 'Drupal OTP Verification',
            );
        }
        if($otp_options == 1){
            $fields = array(
                'customerKey' => $customer_key,
                'phone' => $phone,
                'authType' => 'SMS',
                'transactionName' => 'Drupal OTP Verification',
            );
        }
        //echo "<pre>";print_r($fields);exit;
        $field_string = json_encode($fields);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_TIMEOUT, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        //curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
          "Content-Type: application/json",
          $customer_key_header,
          $timestamp_header,
          $authorization_header,)
        );
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);

        $content = curl_exec($ch);
        $trans_status = json_decode($content)->status;
        $tx_id = json_decode($content)->txId;
        curl_close($ch);
    	return array($trans_status, $tx_id);
    }

    public static function Is_Restricted_Domain($email_domain){

      $config = \Drupal::config('otp_verification.settings');

      $enable_domain_restriction = $config->get('miniorange_block_domain_value');

      if($enable_domain_restriction === FALSE)
        return FALSE;

      $domain = isset(explode('@', $email_domain)[1]) ? explode('@', $email_domain)[1] : '';

      if(is_null($domain) || empty($domain))
        return FALSE;

      $blockdomains = $config->get('miniorange_block_domains');
      $blockdomains = explode(';',$blockdomains);
      $white_or_black = $config->get('miniorange_domains_are_white_or_black');

        if($white_or_black==='white'){
            if(array_search($domain, $blockdomains)===FALSE){
                return TRUE;
            }
            else return FALSE;
        }
        elseif ($white_or_black=='black') {
            if(array_search($domain, $blockdomains)===FALSE){
                return FALSE;
            }
            else return TRUE;
        }

    }

    public static function Is_Restricted_Country_Code($phone){

      $config = \Drupal::config('otp_verification.settings');

      $enable_cc_restriction = $config->get('miniorange_enable_country_code_restriction');

      if($enable_cc_restriction === 0)
        return FALSE;

      $country_codes = $config->get('miniorange_country_codes');
      $country_codes = explode(';',$country_codes);
      $allow_or_block = $config->get('miniorange_allow_or_block_country_code');

        if($allow_or_block === 'allow'){

            foreach ($country_codes as $code) {
                if (strpos($phone, $code) !== false)
                    return FALSE;
            }
            
            return TRUE;
        }
        elseif ($allow_or_block=='block') {

            foreach ($country_codes as $code) {
                if (strpos($phone, $code) !== false)
                    return TRUE;
            }

            return FALSE;
        }

    }
    
    public static function load_user_by_name($name) {
        $users = \Drupal::entityTypeManager()
            ->getStorage('user')
            ->loadByProperties([
                'name' => $name,
            ]);

        return $users ? reset($users) : FALSE;
    }
}
